"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2426],{72426:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var r,n,a=l(67294);function i(){return i=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var r in l)Object.prototype.hasOwnProperty.call(l,r)&&(e[r]=l[r])}return e},i.apply(this,arguments)}const s=e=>a.createElement("svg",i({xmlns:"http://www.w3.org/2000/svg",width:24,height:25,fill:"none"},e),r||(r=a.createElement("rect",{width:16,height:16,x:4,y:4.5,fill:"currentColor",rx:2})),n||(n=a.createElement("path",{fill:"#fff",fillRule:"evenodd",d:"m14.72 9.29-4.29 4.3-1.65-1.65a1 1 0 1 0-1.41 1.41l2.35 2.36a1 1 0 0 0 1.41 0l5-5a1 1 0 1 0-1.41-1.42",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=6db28604648524b2116d.chunk.js.map