"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[650],{70650:(e,t,r)=>{r.r(t),r.d(t,{default:()=>c});var n,s=r(67294);function l(){return l=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},l.apply(this,arguments)}const c=e=>s.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=s.createElement("circle",{cx:12,cy:12,r:4,fill:"currentColor"})))}}]);
//# sourceMappingURL=cf05b047f66fac919c76.chunk.js.map