"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[7820],{67820:(e,t,n)=>{n.r(t),n.d(t,{default:()=>s});var r,l=n(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},a.apply(this,arguments)}const s=e=>l.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),r||(r=l.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M19 11h-6V5a1 1 0 1 0-2 0v6H5a1 1 0 1 0 0 2h6v6a1 1 0 1 0 2 0v-6h6a1 1 0 1 0 0-2",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=d027403e202b8000cc7f.chunk.js.map