"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[894],{40894:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var n,r=l(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var n in l)Object.prototype.hasOwnProperty.call(l,n)&&(e[n]=l[n])}return e},a.apply(this,arguments)}const s=e=>r.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M15.945 10.79a.5.5 0 0 0-.445-.274h-2.502V7.524a.501.501 0 0 0-.906-.32L8.09 12.692a.5.5 0 0 0-.04.499.5.5 0 0 0 .445.319h2.502V16.5a.5.5 0 0 0 .5.499c.16 0 .311-.076.406-.204l4.003-5.487a.5.5 0 0 0 .04-.518m-3.949 4.18v-2.461H9.46L12 9.029l-.001 1.487v1h2.518z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=6e52f42a033e1f898877.chunk.js.map