"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[1016],{5336:(e,h,t)=>{t.r(h),t.d(h,{default:()=>v});var l,a,n=t(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var h=1;h<arguments.length;h++){var t=arguments[h];for(var l in t)Object.prototype.hasOwnProperty.call(t,l)&&(e[l]=t[l])}return e},r.apply(this,arguments)}const v=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:25,fill:"none"},e),l||(l=n.createElement("path",{fill:"#136478",d:"M4 4.5h16v16H4z"})),a||(a=n.createElement("path",{fill:"#A5DBE9",fillRule:"evenodd",d:"M21 2.5H3a1 1 0 0 0-1 1v18a1 1 0 0 0 1 1h18a1 1 0 0 0 1-1v-18a1 1 0 0 0-1-1m-13 18H4v-4h4zm0-6H4v-4h4zm0-6H4v-4h4zm6 12h-4v-4h4zm0-6h-4v-4h4zm0-6h-4v-4h4zm6 12h-4v-4h4zm0-6h-4v-4h4zm0-6h-4v-4h4z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=811a44fa87f89b89e725.chunk.js.map