"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[8701],{88701:(t,i,e)=>{e.r(i),e.d(i,{default:()=>l}),e(67294);var a=e(9857),n=e(61988),h=e(11965);function l({data:t,initialMinEventCount:i,height:e=400,width:l=400}){return t?(0,h.tZ)(a.App,{width:l,height:e,data:t,initialMinEventCount:i,initialShowControls:!1}):(0,h.tZ)("div",{style:{height:e,width:l}},(0,h.tZ)("div",null,(0,n.t)("Sorry, there appears to be no data")))}}}]);
//# sourceMappingURL=2878bd95d4c5369888b3.chunk.js.map