"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[8430],{98430:(e,t,a)=>{a.r(t),a.d(t,{default:()=>h});var l,n,r=a(67294);function o(){return o=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var l in a)Object.prototype.hasOwnProperty.call(a,l)&&(e[l]=a[l])}return e},o.apply(this,arguments)}const h=e=>r.createElement("svg",o({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M21 20H4V3H3v18h18z",clipRule:"evenodd"})),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M17 4a1 1 0 0 0-1 1v13a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1V5a1 1 0 0 0-1-1zm-6 4a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1zm-5 3a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=e2426a2f5ad3fc3f017a.chunk.js.map