"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[7850],{27850:(t,e,r)=>{r.r(e),r.d(e,{default:()=>l});var n,s=r(67294);function a(){return a=Object.assign?Object.assign.bind():function(t){for(var e=1;e<arguments.length;e++){var r=arguments[e];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(t[n]=r[n])}return t},a.apply(this,arguments)}const l=t=>s.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},t),n||(n=s.createElement("path",{fill:"currentColor",d:"M2 2h20v20H2z"})))}}]);
//# sourceMappingURL=61bc1c6f415c8238da97.chunk.js.map