"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[7822],{7822:(e,t,l)=>{l.r(t),l.d(t,{default:()=>i});var n,r,a=l(67294);function c(){return c=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var n in l)Object.prototype.hasOwnProperty.call(l,n)&&(e[n]=l[n])}return e},c.apply(this,arguments)}const i=e=>a.createElement("svg",c({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=a.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M12 18a6 6 0 1 0 0-12 6 6 0 0 0 0 12",clipRule:"evenodd"})),r||(r=a.createElement("path",{fill:"#fff",fillRule:"evenodd",d:"M12 16c-.552 0-1-.373-1-.833V12h-1v-1h2c.552 0 1 .373 1 .833v3.334c0 .46-.448.833-1 .833m-1-7a1 1 0 1 0 2 0 1 1 0 0 0-2 0",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=974d5b024c3cca5caa8c.chunk.js.map