"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[5725],{85725:(e,t,l)=>{l.r(t),l.d(t,{default:()=>i});var n,a,r=l(67294);function s(){return s=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var n in l)Object.prototype.hasOwnProperty.call(l,n)&&(e[n]=l[n])}return e},s.apply(this,arguments)}const i=e=>r.createElement("svg",s({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M12 2C6.477 2 2 6.477 2 12s4.477 10 10 10 10-4.477 10-10A10 10 0 0 0 12 2",clipRule:"evenodd"})),a||(a=r.createElement("path",{fill:"#fff",fillRule:"evenodd",d:"M11 8a1 1 0 1 1 2 0v4a1 1 0 1 1-2 0zm.29 7.29a1 1 0 0 1 .33-.21 1 1 0 0 1 .76 0q.186.073.33.21c.183.192.287.445.29.71a1 1 0 0 1-1.38.92 1.2 1.2 0 0 1-.33-.21A1 1 0 0 1 11 16a.84.84 0 0 1 .08-.38q.076-.183.21-.33",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=73faa63e7d3103a766cc.chunk.js.map