"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[4376],{84376:(e,t,a)=>{a.r(t),a.d(t,{default:()=>s});var l,n=a(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var l in a)Object.prototype.hasOwnProperty.call(a,l)&&(e[l]=a[l])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M20 8.94a1.3 1.3 0 0 0-.06-.27v-.09a1 1 0 0 0-.19-.28l-6-6a1 1 0 0 0-.28-.19h-.09L13.06 2H7a3 3 0 0 0-3 3v14a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V8.94m-6-3.53L16.59 8H14zM18 19a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V5a1 1 0 0 1 1-1h5v5a1 1 0 0 0 1 1h5z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=808098ce0bdfc511a0ba.chunk.js.map