"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[1378],{51378:(t,e,r)=>{r.r(e),r.d(e,{default:()=>s});var h,n=r(67294);function l(){return l=Object.assign?Object.assign.bind():function(t){for(var e=1;e<arguments.length;e++){var r=arguments[e];for(var h in r)Object.prototype.hasOwnProperty.call(r,h)&&(t[h]=r[h])}return t},l.apply(this,arguments)}const s=t=>n.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:17,height:17,fill:"none"},t),h||(h=n.createElement("path",{fill:"currentColor",fillOpacity:.85,d:"M14.167 7.084V5.667h-2.833V2.834H9.917v2.833H7.084V2.834H5.667v2.833H2.834v1.417h2.833v2.833H2.834v1.417h2.833v2.833h1.417v-2.833h2.833v2.833h1.417v-2.833h2.833V9.917h-2.833V7.084zm-4.25 2.833H7.084V7.084h2.833z"})))}}]);
//# sourceMappingURL=6ddaecbf09fb5d53ed92.chunk.js.map