"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[6878],{26878:(a,e,t)=>{t.r(e),t.d(e,{default:()=>h});var n,r=t(67294);function l(){return l=Object.assign?Object.assign.bind():function(a){for(var e=1;e<arguments.length;e++){var t=arguments[e];for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(a[n]=t[n])}return a},l.apply(this,arguments)}const h=a=>r.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},a),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M11 13a1 1 0 1 0 0 2 1 1 0 0 0 0-2m-4 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2m15-9a3 3 0 0 0-3-3H5a3 3 0 0 0-3 3v4a3 3 0 0 0 .78 2A3 3 0 0 0 2 12v4a3 3 0 0 0 3 3h6v2H3a1 1 0 1 0 0 2h18a1 1 0 1 0 0-2h-8v-2h6a3 3 0 0 0 3-3v-4a3 3 0 0 0-.78-2A3 3 0 0 0 22 8zm-2 12a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1v-4a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1zm0-8a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1zm-9-3a1 1 0 1 0 0 2 1 1 0 0 0 0-2M7 5a1 1 0 1 0 0 2 1 1 0 0 0 0-2",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=6ed6195490024fc27b4a.chunk.js.map