"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[5869],{25869:(e,a,t)=>{t.r(a),t.d(a,{default:()=>s});var l,n=t(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var a=1;a<arguments.length;a++){var t=arguments[a];for(var l in t)Object.prototype.hasOwnProperty.call(t,l)&&(e[l]=t[l])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M8.71 7.71 11 5.41V15a1 1 0 1 0 2 0V5.41l2.29 2.3a1 1 0 0 0 1.42 0 1 1 0 0 0 0-1.42l-4-4a1 1 0 0 0-.33-.21 1 1 0 0 0-.76 0 1 1 0 0 0-.33.21l-4 4a1.004 1.004 0 0 0 1.42 1.42M21 12a1 1 0 0 0-1 1v6a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1v-6a1 1 0 1 0-2 0v6a3 3 0 0 0 3 3h14a3 3 0 0 0 3-3v-6a1 1 0 0 0-1-1",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=333dc13f9b6cdb7d0132.chunk.js.map