"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2237],{92237:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var n,r=l(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var n in l)Object.prototype.hasOwnProperty.call(l,n)&&(e[n]=l[n])}return e},a.apply(this,arguments)}const s=e=>r.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M8 6a1 1 0 1 0 0 2 1 1 0 0 0 0-2m14.71 5.78-9.48-9.46A1 1 0 0 0 12.5 2h-6a1 1 0 0 0-.71.29l-2.5 2.49a1 1 0 0 0-.29.71v6c.004.265.107.518.29.71l9.49 9.5c.192.183.445.286.71.29a1 1 0 0 0 .71-.29l8.51-8.51a1 1 0 0 0 .29-.71 1.05 1.05 0 0 0-.29-.7m-9.22 7.81L5 11.09V5.9L6.9 4h5.18l8.5 8.49z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=bc10cc926c55c21519ce.chunk.js.map