"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[84],{84:(e,t,a)=>{a.r(t),a.d(t,{default:()=>s});var n,r=a(67294);function l(){return l=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var n in a)Object.prototype.hasOwnProperty.call(a,n)&&(e[n]=a[n])}return e},l.apply(this,arguments)}const s=e=>r.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M18.328 14.808h-3.624a.8.8 0 0 0 0 1.6h1.92A6.4 6.4 0 0 1 5.6 12 .8.8 0 0 0 4 12a8 8 0 0 0 13.504 5.784V19.2a.8.8 0 0 0 1.6 0v-3.6a.8.8 0 0 0-.776-.792M12 4a8 8 0 0 0-5.504 2.216V4.8a.8.8 0 1 0-1.6 0v3.6a.8.8 0 0 0 .8.8h3.6a.8.8 0 1 0 0-1.6h-1.92A6.4 6.4 0 0 1 18.4 12a.8.8 0 0 0 1.6 0 8 8 0 0 0-8-8",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=b677080e5ca4020767a6.chunk.js.map