"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[3246],{82968:(e,t,n)=>{n.r(t),n.d(t,{default:()=>s});var r,l=n(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},a.apply(this,arguments)}const s=e=>l.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),r||(r=l.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M12 10a2 2 0 1 0 0 4 2 2 0 0 0 0-4m-7 0a2 2 0 1 0 0 4 2 2 0 0 0 0-4m14 0a2 2 0 1 0 0 4 2 2 0 0 0 0-4",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=81d638c1e1b2a2847fec.chunk.js.map