"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[8225],{48225:(e,t,a)=>{a.r(t),a.d(t,{default:()=>s});var n,r=a(67294);function l(){return l=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var n in a)Object.prototype.hasOwnProperty.call(a,n)&&(e[n]=a[n])}return e},l.apply(this,arguments)}const s=e=>r.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M10.5 16a1 1 0 0 0 1 1h1a1 1 0 1 0 0-2h-1a1 1 0 0 0-1 1m-4-9a1 1 0 0 0 0 2h11a1 1 0 1 0 0-2zm2 5a1 1 0 0 0 1 1h5a1 1 0 1 0 0-2h-5a1 1 0 0 0-1 1",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=4e65870af7b5c886fb75.chunk.js.map