"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[4801],{34801:(e,h,t)=>{t.r(h),t.d(h,{default:()=>s});var n,r=t(67294);function l(){return l=Object.assign?Object.assign.bind():function(e){for(var h=1;h<arguments.length;h++){var t=arguments[h];for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])}return e},l.apply(this,arguments)}const s=e=>r.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M7 7h2v2H7zm0 4h2v2H7zm4 0h2v2h-2zm6 0h-2v2h2zm-8 4H7v2h2zm4 0h-2v2h2zm2 0h2v2h-2zm-4-8h2v2h-2zm6 0h-2v2h2z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=c5f94b1e8908a48cbd0f.chunk.js.map