"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[6384],{97589:(e,t,l)=>{l.r(t),l.d(t,{default:()=>a});var n,r=l(67294);function s(){return s=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var n in l)Object.prototype.hasOwnProperty.call(l,n)&&(e[n]=l[n])}return e},s.apply(this,arguments)}const a=e=>r.createElement("svg",s({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M10.414 10c-.89 0-1.337 1.077-.707 1.707l1.586 1.586a1 1 0 0 0 1.414 0l1.586-1.586c.63-.63.184-1.707-.707-1.707z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=a9d8a6af8e900907c2e3.chunk.js.map