"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[4749],{84749:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var a,n=l(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var a in l)Object.prototype.hasOwnProperty.call(l,a)&&(e[a]=l[a])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),a||(a=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M5 18.506h4.24a1 1 0 0 0 .71-.29l6.92-6.93 2.84-2.78a1 1 0 0 0 0-1.42l-4.24-4.29a1 1 0 0 0-1.42 0l-2.82 2.83-6.94 6.93a1 1 0 0 0-.29.71v4.24a1 1 0 0 0 1 1m9.76-13.59 2.83 2.83-1.42 1.42-2.83-2.83zM6 13.676l5.93-5.93 2.83 2.83-5.93 5.93H6zm15 6.83H3a1 1 0 1 0 0 2h18a1 1 0 1 0 0-2",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=caa52611d81bb2278a91.chunk.js.map