"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[8960],{58960:(e,a,t)=>{t.r(a),t.d(a,{default:()=>s});var l,n=t(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var a=1;a<arguments.length;a++){var t=arguments[a];for(var l in t)Object.prototype.hasOwnProperty.call(t,l)&&(e[l]=t[l])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"m20 8.024-6-5.26a3 3 0 0 0-4 0l-6 5.26a3 3 0 0 0-1 2.26v8.74a3 3 0 0 0 3 3h12a3 3 0 0 0 3-3v-8.75a3 3 0 0 0-1-2.25m-6 12h-4v-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1zm5-1a1 1 0 0 1-1 1h-2v-5a3 3 0 0 0-3-3h-2a3 3 0 0 0-3 3v5H6a1 1 0 0 1-1-1v-8.75a1 1 0 0 1 .34-.75l6-5.25a1 1 0 0 1 1.32 0l6 5.25a1 1 0 0 1 .34.75z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=95e735d0b7d803b55e2a.chunk.js.map