"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[7461],{27461:(e,t,h)=>{h.r(t),h.d(t,{default:()=>v});var n,r=h(67294);function l(){return l=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var h=arguments[t];for(var n in h)Object.prototype.hasOwnProperty.call(h,n)&&(e[n]=h[n])}return e},l.apply(this,arguments)}const v=e=>r.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M10 8h1v2h2V8h1v2h2v1h-2v2h2v1h-2v2h-1v-2h-2v2h-1v-2H8v-1h2v-2H8v-1h2zm3 5v-2h-2v2z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=6541d63a744196cdb691.chunk.js.map