"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[7239],{77239:(e,a,t)=>{t.r(a),t.d(a,{default:()=>s});var l,n=t(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var a=1;a<arguments.length;a++){var t=arguments[a];for(var l in t)Object.prototype.hasOwnProperty.call(t,l)&&(e[l]=t[l])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M8.29 11.29a1 1 0 0 0 0 1.42l3 3a1 1 0 0 0 1.42 0l3-3a1.004 1.004 0 0 0-1.42-1.42L13 12.59V3a1 1 0 1 0-2 0v9.59l-1.29-1.3a1 1 0 0 0-1.42 0M18 7h-2a1 1 0 1 0 0 2h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1v-7a1 1 0 0 1 1-1h2a1 1 0 0 0 0-2H6a3 3 0 0 0-3 3v7a3 3 0 0 0 3 3h12a3 3 0 0 0 3-3v-7a3 3 0 0 0-3-3",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=383da82277b99641c12e.chunk.js.map