"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[389],{80389:(e,h,t)=>{t.r(h),t.d(h,{default:()=>s});var l,n,r=t(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var h=1;h<arguments.length;h++){var t=arguments[h];for(var l in t)Object.prototype.hasOwnProperty.call(t,l)&&(e[l]=t[l])}return e},a.apply(this,arguments)}const s=e=>r.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=r.createElement("path",{fill:"currentColor",d:"M4 4h16v16H4z"})),n||(n=r.createElement("path",{fill:"#E0E0E0",fillRule:"evenodd",d:"M21 2H3a1 1 0 0 0-1 1v18a1 1 0 0 0 1 1h18a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1M8 20H4v-4h4zm0-6H4v-4h4zm0-6H4V4h4zm6 12h-4v-4h4zm0-6h-4v-4h4zm0-6h-4V4h4zm6 12h-4v-4h4zm0-6h-4v-4h4zm0-6h-4V4h4z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=315b732216cb8c75dd48.chunk.js.map