"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[7539],{67539:(e,t,l)=>{l.r(t),l.d(t,{default:()=>i});var n,r,a=l(67294);function s(){return s=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var n in l)Object.prototype.hasOwnProperty.call(l,n)&&(e[n]=l[n])}return e},s.apply(this,arguments)}const i=e=>a.createElement("svg",s({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=a.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M12 2C6.477 2 2 6.477 2 12s4.477 10 10 10 10-4.477 10-10A10 10 0 0 0 12 2",clipRule:"evenodd"})),r||(r=a.createElement("path",{fill:"#fff",fillRule:"evenodd",d:"M16 11H8a1 1 0 1 0 0 2h8a1 1 0 1 0 0-2",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=d431fb54ab2a4d8c8668.chunk.js.map