"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[9480],{89480:(e,t,n)=>{n.r(t),n.d(t,{default:()=>h});var r,l=n(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},a.apply(this,arguments)}const h=e=>l.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),r||(r=l.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M21 2H3a1 1 0 0 0-1 1v18a1 1 0 0 0 1 1h18a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1M11 20H4v-7h7zm0-9H4V4h7zm9 9h-7v-7h7zm0-9h-7V4h7z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=f7fa129d909d8393a8a0.chunk.js.map