"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2132],{11950:(e,t,n)=>{var r=n(64836),i=n(16338);Object.defineProperty(t,"__esModule",{value:!0}),t.default=t.HOOK_MARK=void 0;var a=i(n(67294)),o=r(n(45520));t.HOOK_MARK="RC_FORM_INTERNAL_HOOKS";var l=function(){(0,o.default)(!1,"Can not find FormContext. Please make sure you wrap Field under Form.")},u=a.createContext({getFieldValue:l,getFieldsValue:l,getFieldError:l,getFieldsError:l,isFieldsTouched:l,isFieldTouched:l,isFieldValidating:l,isFieldsValidating:l,resetFields:l,setFields:l,setFieldsValue:l,validateFields:l,submit:l,getInternalHooks:function(){return l(),{dispatch:l,initEntityValue:l,registerField:l,useSubscribe:l,setInitialValues:l,setCallbacks:l,getFields:l,setValidateMessages:l,setPreserve:l}}});t.default=u},67265:(e,t,n)=>{var r=n(16338).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,n){var r=i.useRef({});return"value"in r.current&&!n(r.current.condition,t)||(r.current.value=e(),r.current.condition=t),r.current.value};var i=r(n(67294))},64543:(e,t)=>{Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n=function(e){return+setTimeout(e,16)},r=function(e){return clearTimeout(e)};"undefined"!=typeof window&&"requestAnimationFrame"in window&&(n=function(e){return window.requestAnimationFrame(e)},r=function(e){return window.cancelAnimationFrame(e)});var i=0,a=new Map;function o(e){a.delete(e)}var l=function(e){var t=i+=1;return function r(i){if(0===i)o(t),e();else{var l=n((function(){r(i-1)}));a.set(t,l)}}(arguments.length>1&&void 0!==arguments[1]?arguments[1]:1),t};l.cancel=function(e){var t=a.get(e);return o(e),r(t)},t.default=l},75531:(e,t,n)=>{var r=n(64836).default;Object.defineProperty(t,"__esModule",{value:!0}),t.composeRef=s,t.fillRef=u,t.supportNodeRef=function(e){return!!(0,a.isValidElement)(e)&&(!(0,o.isFragment)(e)&&d(e))},t.supportRef=d,t.useComposeRef=function(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return(0,l.default)((function(){return s.apply(void 0,t)}),t,(function(e,t){return e.length!==t.length||e.every((function(e,n){return e!==t[n]}))}))};var i=r(n(18698)),a=n(67294),o=n(11805),l=r(n(67265));function u(e,t){"function"==typeof e?e(t):"object"===(0,i.default)(e)&&e&&"current"in e&&(e.current=t)}function s(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];var r=t.filter((function(e){return e}));return r.length<=1?r[0]:function(e){t.forEach((function(t){u(t,e)}))}}function d(e){var t,n,r=(0,o.isMemo)(e)?e.type.type:e.type;return!!("function"!=typeof r||null!==(t=r.prototype)&&void 0!==t&&t.render)&&!!("function"!=typeof e||null!==(n=e.prototype)&&void 0!==n&&n.render)}},4591:(e,t,n)=>{n.d(t,{Z:()=>i});var r=n(97538);const i=(0,n(51995).iK)(r.Z.Item)`
  ${({theme:e})=>`\n    .ant-form-item-label {\n      padding-bottom: ${e.gridUnit}px;\n      & > label {\n        text-transform: uppercase;\n        font-size: ${e.typography.sizes.s}px;\n        color: ${e.colors.grayscale.base};\n\n        &.ant-form-item-required:not(.ant-form-item-required-mark-optional) {\n          &::before {\n            display: none;\n          }\n          &::after {\n            display: inline-block;\n            color: ${e.colors.error.base};\n            font-size: ${e.typography.sizes.s}px;\n            content: '*';\n          }\n        }\n      }\n    }\n  `}
`},24572:(e,t,n)=>{n.r(t),n.d(t,{default:()=>c});var r=n(73126),i=n(55786),a=n(88889),o=n(61988),l=n(67294),u=n(4715),s=n(74448),d=n(11965);function c(e){const{data:t,formData:n,height:c,width:f,setDataMask:p,setHoveredFilter:v,unsetHoveredFilter:m,setFocusedFilter:g,unsetFocusedFilter:h,setFilterActive:F,filterState:y,inputRef:b}=e,{defaultValue:w}=n,[_,M]=(0,l.useState)(null!=w?w:[]),O=e=>{const t=(0,i.Z)(e);M(t);const n={};t.length&&(n.granularity_sqla=t[0]),p({extraFormData:n,filterState:{value:t.length?t:null}})};(0,l.useEffect)((()=>{O(null!=w?w:null)}),[JSON.stringify(w)]),(0,l.useEffect)((()=>{var e;O(null!=(e=y.value)?e:null)}),[JSON.stringify(y.value)]);const R=(t||[]).filter((e=>e.dtype===a.Z.Temporal)),A=0===R.length?(0,o.t)("No time columns"):(0,o.tn)("%s option","%s options",R.length,R.length),C={};y.validateMessage&&(C.extra=(0,d.tZ)(s.Am,{status:y.validateStatus},y.validateMessage));const V=R.map((e=>{const{column_name:t,verbose_name:n}=e;return{label:null!=n?n:t,value:t}}));return(0,d.tZ)(s.un,{height:c,width:f},(0,d.tZ)(s.jp,(0,r.Z)({validateStatus:y.validateStatus},C),(0,d.tZ)(u.Ph,{allowClear:!0,value:_,placeholder:A,onChange:O,onBlur:h,onFocus:g,onMouseEnter:v,onMouseLeave:m,ref:b,options:V,onDropdownVisibleChange:F})))}},74448:(e,t,n)=>{n.d(t,{Am:()=>u,h2:()=>a,jp:()=>l,un:()=>o});var r=n(51995),i=n(4591);const a=0,o=r.iK.div`
  min-height: ${({height:e})=>e}px;
  width: ${({width:e})=>e===a?"100%":`${e}px`};
`,l=(0,r.iK)(i.Z)`
  &.ant-row.ant-form-item {
    margin: 0;
  }
`,u=r.iK.div`
  color: ${({theme:e,status:t="error"})=>{var n;return null==(n=e.colors[t])?void 0:n.base}};
`}}]);
//# sourceMappingURL=0a9100e9142f9fd7e6b4.chunk.js.map