"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[9684],{99684:(e,t,r)=>{r.r(t),r.d(t,{default:()=>s});var l,n,a=r(67294);function h(){return h=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var l in r)Object.prototype.hasOwnProperty.call(r,l)&&(e[l]=r[l])}return e},h.apply(this,arguments)}const s=e=>a.createElement("svg",h({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=a.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M21 2H3a1 1 0 0 0-1 1v18a1 1 0 0 0 1 1h18a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1M11 20H4v-4h7zm0-6H4v-4h7zm9 6h-7v-4h7zm0-6h-7v-4h7zm0-6H4V4h16z",clipRule:"evenodd"})),n||(n=a.createElement("path",{fill:"currentColor",d:"M4 4h16v4H4z"})))}}]);
//# sourceMappingURL=d66e914e04b6e1896e39.chunk.js.map