"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[3043],{13043:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var a,n=l(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var a in l)Object.prototype.hasOwnProperty.call(l,a)&&(e[a]=l[a])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),a||(a=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M6.465 19.25v-7.027a3.75 3.75 0 0 1 3.75-3.75h5.25l-2.22-2.19a.75.75 0 1 1 1.057-1.065l3.473 3.472a.8.8 0 0 1 .165.248c.08.181.08.388 0 .57a.9.9 0 0 1-.165.247l-3.473 3.495a.75.75 0 0 1-1.057-1.057l2.19-2.22h-5.25a2.25 2.25 0 0 0-2.25 2.25v7.027a.75.75 0 1 1-1.5 0z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=81cdcea6c675cebcf229.chunk.js.map