"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[5922],{25922:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var a,n=l(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var a in l)Object.prototype.hasOwnProperty.call(l,a)&&(e[a]=l[a])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),a||(a=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"m20.34 9.32-14-7a3 3 0 0 0-4.08 3.9l2.4 5.37c.11.262.11.558 0 .82l-2.4 5.37A3 3 0 0 0 5 22a3.14 3.14 0 0 0 1.35-.32l14-7a3 3 0 0 0 0-5.36zm-.89 3.57-14 7a1 1 0 0 1-1.35-1.3l2.39-5.37q.045-.108.08-.22h6.89a1 1 0 1 0 0-2H6.57a2 2 0 0 0-.08-.22L4.1 5.41a1 1 0 0 1 1.35-1.3l14 7a1 1 0 0 1 0 1.78",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=6c73ef913f51fc39b348.chunk.js.map