"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2405],{72405:(e,l,t)=>{t.r(l),t.d(l,{default:()=>s});var a,n=t(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var l=1;l<arguments.length;l++){var t=arguments[l];for(var a in t)Object.prototype.hasOwnProperty.call(t,a)&&(e[a]=t[a])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),a||(a=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M21.92 11.62a1 1 0 0 0-.21-.33l-4-4a1.004 1.004 0 0 0-1.42 1.42l2.3 2.29H5.41l2.3-2.29a1.004 1.004 0 1 0-1.42-1.42l-4 4a1 1 0 0 0-.21.33 1 1 0 0 0 0 .76 1 1 0 0 0 .21.33l4 4a1 1 0 0 0 1.42 0 1 1 0 0 0 0-1.42L5.41 13h13.18l-2.3 2.29a1 1 0 0 0 0 1.42 1 1 0 0 0 1.42 0l4-4q.139-.144.21-.33a1 1 0 0 0 0-.76",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=8782211c81f2ba755edc.chunk.js.map