"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[511],{90511:(e,t,a)=>{a.r(t),a.d(t,{default:()=>s});var l,n=a(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var l in a)Object.prototype.hasOwnProperty.call(a,l)&&(e[l]=a[l])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M4 4v16h16V7.828l-3-3V6a2 2 0 0 1-2 2H9a2 2 0 0 1-2-2V4zm5 0h6v2H9zm6-2h2l5 5v13a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h11m-1 12a2 2 0 1 1-4 0 2 2 0 0 1 4 0m2 0a4 4 0 1 1-8 0 4 4 0 0 1 8 0",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=3ff20c4ce5e1e67be2cd.chunk.js.map