"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2078],{82078:(e,l,t)=>{t.r(l),t.d(l,{default:()=>i});var n,r,a=t(67294);function s(){return s=Object.assign?Object.assign.bind():function(e){for(var l=1;l<arguments.length;l++){var t=arguments[l];for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])}return e},s.apply(this,arguments)}const i=e=>a.createElement("svg",s({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=a.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M12 2C6.477 2 2 6.477 2 12s4.477 10 10 10 10-4.477 10-10A10 10 0 0 0 12 2",clipRule:"evenodd"})),r||(r=a.createElement("path",{fill:"#fff",fillRule:"evenodd",d:"m14.72 8.79-4.29 4.3-1.65-1.65a1 1 0 1 0-1.41 1.41l2.35 2.36a1 1 0 0 0 1.41 0l5-5a1 1 0 1 0-1.41-1.42",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=14b43c1d55d5c32058c5.chunk.js.map