"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[6362],{90170:(s,e,r)=>{r.r(e),r.d(e,{default:()=>l}),r(67294);var u=r(16550),a=r(57001),t=r(11965);const l=()=>{const{idOrSlug:s}=(0,u.UO)();return(0,t.tZ)(a.DashboardPage,{idOrSlug:s})}}}]);
//# sourceMappingURL=b94c2f0d86469aa6367d.chunk.js.map