"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[1603],{31603:(e,t,n)=>{n.r(t),n.d(t,{default:()=>a});var r,l=n(67294);function s(){return s=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},s.apply(this,arguments)}const a=e=>l.createElement("svg",s({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),r||(r=l.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M2 12C2 6.48 6.48 2 12 2s10 4.48 10 10-4.48 10-10 10S2 17.52 2 12m18 0a8 8 0 1 1-16 0 8 8 0 0 1 16 0",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=f9e3224b7a30edf282a0.chunk.js.map