"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[8754],{38754:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var n,r=l(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var n in l)Object.prototype.hasOwnProperty.call(l,n)&&(e[n]=l[n])}return e},a.apply(this,arguments)}const s=e=>r.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M17 14.83a1 1 0 0 1-1.41 0L12 11.29l-3.54 3.54a1 1 0 1 1-1.41-1.42l4.24-4.24a1 1 0 0 1 1.42 0L17 13.41a1 1 0 0 1 0 1.42",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=6f12fa157bd3f7014744.chunk.js.map