"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[3489],{73489:(e,t,n)=>{n.r(t),n.d(t,{default:()=>s});var r,l=n(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},a.apply(this,arguments)}const s=e=>l.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),r||(r=l.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M11 12h-1v-1h2a1 1 0 0 1 1 1v4h1v1h-4v-1h1zm1.38-4.92a1 1 0 0 0-.76 0 1 1 0 0 0-.33.21 1.2 1.2 0 0 0-.21.33 1 1 0 0 0 .21 1.09q.147.133.33.21A1 1 0 0 0 13 8a1.05 1.05 0 0 0-.29-.71 1 1 0 0 0-.33-.21M12 2C6.477 2 2 6.477 2 12s4.477 10 10 10 10-4.477 10-10A10 10 0 0 0 12 2m0 18a8 8 0 1 1 0-16 8 8 0 0 1 0 16",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=47f830a223d159504dac.chunk.js.map