"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[5481],{65481:(e,t,a)=>{a.r(t),a.d(t,{default:()=>s});var l,n=a(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var l in a)Object.prototype.hasOwnProperty.call(a,l)&&(e[l]=a[l])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),l||(l=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"m7.29 11.29 4-4a1.004 1.004 0 0 1 1.42 1.42L10.41 11H19a1 1 0 1 1 0 2h-8.59l2.3 2.29a1 1 0 0 1 0 1.42 1 1 0 0 1-1.42 0l-4-4a1 1 0 0 1-.21-.33 1 1 0 0 1 0-.76 1 1 0 0 1 .21-.33M4 4a1 1 0 0 1 1 1v14a1 1 0 1 1-2 0V5a1 1 0 0 1 1-1",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=4b824584ad95d95da8d1.chunk.js.map