"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2417],{22417:(e,t,a)=>{a.r(t),a.d(t,{default:()=>s});var n,r=a(67294);function l(){return l=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var n in a)Object.prototype.hasOwnProperty.call(a,n)&&(e[n]=a[n])}return e},l.apply(this,arguments)}const s=e=>r.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M15 7H9v.5a.5.5 0 0 1-1 0V7H6.5A1.5 1.5 0 0 0 5 8.5V11h14V8.5A1.5 1.5 0 0 0 17.5 7H16v.5a.5.5 0 0 1-1 0zm1-1h1.5A2.5 2.5 0 0 1 20 8.5v8.007a2.5 2.5 0 0 1-2.5 2.5h-11a2.5 2.5 0 0 1-2.5-2.5V8.5A2.5 2.5 0 0 1 6.5 6H8v-.5a.5.5 0 0 1 1 0V6h6v-.5a.5.5 0 0 1 1 0zM5 12v4.507a1.5 1.5 0 0 0 1.5 1.5h11a1.5 1.5 0 0 0 1.5-1.5V12z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=a9475beec1eb07078e2b.chunk.js.map