"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[8277],{48277:(e,t,l)=>{l.r(t),l.d(t,{default:()=>c});var a,n,r=l(67294);function s(){return s=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var a in l)Object.prototype.hasOwnProperty.call(l,a)&&(e[a]=l[a])}return e},s.apply(this,arguments)}const c=e=>r.createElement("svg",s({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"currentColor"},e),a||(a=r.createElement("path",{fillRule:"evenodd",d:"m21.71 7.56-5.27-5.27a1.05 1.05 0 0 0-.71-.29H8.27a1.05 1.05 0 0 0-.71.29L2.29 7.56a1.05 1.05 0 0 0-.29.71v7.46c.004.265.107.518.29.71l5.27 5.27c.192.183.445.286.71.29h7.46a1.05 1.05 0 0 0 .71-.29l5.27-5.27a1.05 1.05 0 0 0 .29-.71V8.27a1.05 1.05 0 0 0-.29-.71",clipRule:"evenodd"})),n||(n=r.createElement("path",{fill:"#fff",fillRule:"evenodd",d:"M11 8a1 1 0 1 1 2 0v4a1 1 0 1 1-2 0zm0 8a1 1 0 1 1 2 0 1 1 0 0 1-2 0",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=d3e9cabbf4132ca1070d.chunk.js.map