"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[5280],{25280:(e,a,t)=>{t.r(a),t.d(a,{default:()=>s});var n,r=t(67294);function l(){return l=Object.assign?Object.assign.bind():function(e){for(var a=1;a<arguments.length;a++){var t=arguments[a];for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])}return e},l.apply(this,arguments)}const s=e=>r.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M12 13a1.49 1.49 0 0 0-1 2.61V17a1 1 0 1 0 2 0v-1.39A1.49 1.49 0 0 0 12 13m5-4H9V7a3 3 0 0 1 5.12-2.13c.376.384.645.86.78 1.38a1.002 1.002 0 1 0 1.94-.5 5.1 5.1 0 0 0-1.31-2.29A5 5 0 0 0 7 7v2a3 3 0 0 0-3 3v7a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3v-7a3 3 0 0 0-3-3m1 10a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1v-7a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=4388940c6dfc1b5df928.chunk.js.map