"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[287],{70287:(t,e,r)=>{r.r(e),r.d(e,{default:()=>a});var h,n=r(67294);function s(){return s=Object.assign?Object.assign.bind():function(t){for(var e=1;e<arguments.length;e++){var r=arguments[e];for(var h in r)Object.prototype.hasOwnProperty.call(r,h)&&(t[h]=r[h])}return t},s.apply(this,arguments)}const a=t=>n.createElement("svg",s({xmlns:"http://www.w3.org/2000/svg",width:16,height:16,fill:"none"},t),h||(h=n.createElement("path",{fill:"currentColor",d:"M8.667 5H12v1.333H8.667zm0 4.667H12V11H8.667zm4-7.667H3.333C2.6 2 2 2.6 2 3.333v9.334C2 13.4 2.6 14 3.333 14h9.334C13.4 14 14 13.4 14 12.667V3.333C14 2.6 13.4 2 12.667 2m0 10.667H3.333V3.333h9.334zM7.333 4H4v3.333h3.333zm-.666 2.667h-2v-2h2zm.666 2H4V12h3.333zm-.666 2.666h-2v-2h2z"})))}}]);
//# sourceMappingURL=10efa17b90272757f656.chunk.js.map