"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[3348],{73348:(t,o,e)=>{e.r(o),e.d(o,{default:()=>h,getLayer:()=>c});var r=e(92219),l=(e(67294),e(61988)),a=e(58371),n=e(63241),i=e(89691),s=e(51805),u=e(11965);function d(t){var o,e;return(0,u.tZ)("div",{className:"deckgl-tooltip"},(0,u.tZ)(s.Z,{label:(0,l.t)("Centroid (Longitude and Latitude): "),value:`(${null==t?void 0:t.coordinate[0]}, ${null==t?void 0:t.coordinate[1]})`}),(0,u.tZ)(s.Z,{label:(0,l.t)("Threshold: "),value:`${null==t||null==(o=t.object)||null==(e=o.contour)?void 0:e.threshold}`}))}const c=function(t,o,e,l){const i=t,{aggregation:s="SUM",js_data_mutator:u,contours:c,cellSize:h="200"}=i;let g=o.data.features;const p=null==c?void 0:c.map((t=>{const{lowerThreshold:o,upperThreshold:e,color:r,strokeWidth:l}=t;return e?{threshold:[o,e],color:[r.r,r.g,r.b]}:{threshold:o,color:[r.r,r.g,r.b],strokeWidth:l}}));return u&&(g=(0,n.Z)(i.js_data_mutator)(g)),new r.Z({id:`contourLayer-${i.slice_id}`,data:g,contours:p,cellSize:Number(h||"200"),aggregation:s.toUpperCase(),getPosition:t=>t.position,getWeight:t=>t.weight||0,...(0,a.N)(i,l,d)})},h=(0,i.G)(c,(function(t){return t.map((t=>t.position))}))}}]);
//# sourceMappingURL=6c18ff6129087041a0ba.chunk.js.map