"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2663],{15694:(a,e,t)=>{t.r(e),t.d(e,{default:()=>h});var n,r=t(67294);function l(){return l=Object.assign?Object.assign.bind():function(a){for(var e=1;e<arguments.length;e++){var t=arguments[e];for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(a[n]=t[n])}return a},l.apply(this,arguments)}const h=a=>r.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},a),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M10 18.5a1 1 0 0 0 1-1v-6a1 1 0 1 0-2 0v6a1 1 0 0 0 1 1m10-12h-4v-1a3 3 0 0 0-3-3h-2a3 3 0 0 0-3 3v1H4a1 1 0 0 0 0 2h1v11a3 3 0 0 0 3 3h8a3 3 0 0 0 3-3v-11h1a1 1 0 1 0 0-2m-10-1a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v1h-4zm7 14a1 1 0 0 1-1 1H8a1 1 0 0 1-1-1v-11h10zm-3-1a1 1 0 0 0 1-1v-6a1 1 0 1 0-2 0v6a1 1 0 0 0 1 1",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=0022db51115187230801.chunk.js.map