"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[5029],{15029:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var a,n=l(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var a in l)Object.prototype.hasOwnProperty.call(l,a)&&(e[a]=l[a])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),a||(a=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M19.25 17.535h-7.027a3.75 3.75 0 0 1-3.75-3.75v-5.25l-2.19 2.22a.75.75 0 1 1-1.065-1.057L8.69 6.225a.8.8 0 0 1 .248-.165.7.7 0 0 1 .57 0q.138.062.247.165l3.495 3.473a.75.75 0 0 1-1.057 1.057l-2.22-2.19v5.25a2.25 2.25 0 0 0 2.25 2.25h7.027a.75.75 0 0 1 0 1.5z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=11f92a1bb08643ab1839.chunk.js.map