"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[6945],{16945:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var n,r=l(67294);function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var n in l)Object.prototype.hasOwnProperty.call(l,n)&&(e[n]=l[n])}return e},a.apply(this,arguments)}const s=e=>r.createElement("svg",a({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"#E0E0E0",fillRule:"evenodd",d:"M9.707 9.293c-.63.63-.184 1.707.707 1.707h3.172c.89 0 1.337-1.077.707-1.707l-1.586-1.586a1 1 0 0 0-1.414 0zm0 5.414c-.63-.63-.184-1.707.707-1.707h3.172c.89 0 1.337 1.077.707 1.707l-1.586 1.586a1 1 0 0 1-1.414 0z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=0c3dfe09c250db609472.chunk.js.map