"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2886],{2886:(e,l,t)=>{t.r(l),t.d(l,{default:()=>s});var n,a,r=t(67294);function i(){return i=Object.assign?Object.assign.bind():function(e){for(var l=1;l<arguments.length;l++){var t=arguments[l];for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])}return e},i.apply(this,arguments)}const s=e=>r.createElement("svg",i({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),n||(n=r.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"m22.67 17.47-8.05-14a3 3 0 0 0-5.24 0l-8 14A3 3 0 0 0 3.94 22h16.12a3 3 0 0 0 2.61-4.53",clipRule:"evenodd"})),a||(a=r.createElement("path",{fill:"#fff",fillRule:"evenodd",d:"M11 9a1 1 0 1 1 2 0v4a1 1 0 1 1-2 0zm0 8a1 1 0 1 1 2 0 1 1 0 0 1-2 0",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=dbb4989c9a59ab66db6c.chunk.js.map