"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[9414],{29414:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var a,n=l(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var a in l)Object.prototype.hasOwnProperty.call(l,a)&&(e[a]=l[a])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),a||(a=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"m15.71 11.29-4-4a1.004 1.004 0 0 0-1.42 1.42l2.3 2.29H4a1 1 0 1 0 0 2h8.59l-2.3 2.29a1 1 0 0 0 0 1.42 1 1 0 0 0 1.42 0l4-4a1 1 0 0 0 .21-.33 1 1 0 0 0 0-.76 1 1 0 0 0-.21-.33M19 4a1 1 0 0 0-1 1v14a1 1 0 1 0 2 0V5a1 1 0 0 0-1-1",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=5f4569b126909477b59e.chunk.js.map