"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[2837],{72837:(e,t,n)=>{n.r(t),n.d(t,{default:()=>s});var r,a=n(67294);function l(){return l=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},l.apply(this,arguments)}const s=e=>a.createElement("svg",l({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),r||(r=a.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M12 2a10 10 0 0 0-7.35 16.76 10 10 0 0 0 14.7 0A10 10 0 0 0 12 2m0 18a8 8 0 0 1-5.55-2.25 6 6 0 0 1 11.1 0A8 8 0 0 1 12 20m-2-10a2 2 0 1 1 4 0 2 2 0 0 1-4 0m8.91 6A8 8 0 0 0 15 12.62a4 4 0 1 0-6 0A8 8 0 0 0 5.09 16 7.9 7.9 0 0 1 4 12a8 8 0 1 1 16 0 7.9 7.9 0 0 1-1.09 4",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=8443f50d0452b1d9976e.chunk.js.map