"use strict";(globalThis.webpackChunksuperset=globalThis.webpackChunksuperset||[]).push([[6450],{6450:(e,t,l)=>{l.r(t),l.d(t,{default:()=>s});var a,n=l(67294);function r(){return r=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var l=arguments[t];for(var a in l)Object.prototype.hasOwnProperty.call(l,a)&&(e[a]=l[a])}return e},r.apply(this,arguments)}const s=e=>n.createElement("svg",r({xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},e),a||(a=n.createElement("path",{fill:"currentColor",fillRule:"evenodd",d:"M19.89 10.55A1 1 0 0 0 19 10h-5V4a1 1 0 0 0-.69-1 1 1 0 0 0-1.12.36l-8 11a1 1 0 0 0-.08 1A1 1 0 0 0 5 16h5v6a1 1 0 0 0 1 1 1 1 0 0 0 .81-.41l8-11a1 1 0 0 0 .08-1.04M12 18.92V15a1 1 0 0 0-1-1H7l5-6.92V11a1 1 0 0 0 1 1h4z",clipRule:"evenodd"})))}}]);
//# sourceMappingURL=b2ad88e60f6c5f7054d0.chunk.js.map